@@ -7,7 +7,7 @@
 #  define VTKGUISUPPORTQTSQL_NO_EXPORT
 #else
 #  ifndef VTKGUISUPPORTQTSQL_EXPORT
-#    ifdef vtkGUISupportQtSQL_EXPORTS
+#    ifdef GUISupportQtSQL_EXPORTS
         /* We are building this library */
 #      define VTKGUISUPPORTQTSQL_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,16 +23,20 @@
 
 #ifndef VTKGUISUPPORTQTSQL_DEPRECATED
 #  define VTKGUISUPPORTQTSQL_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKGUISUPPORTQTSQL_DEPRECATED_EXPORT VTKGUISUPPORTQTSQL_EXPORT __attribute__ ((__deprecated__))
-#  define VTKGUISUPPORTQTSQL_DEPRECATED_NO_EXPORT VTKGUISUPPORTQTSQL_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKGUISUPPORTQTSQL_NO_DEPRECATED
+#ifndef VTKGUISUPPORTQTSQL_DEPRECATED_EXPORT
+#  define VTKGUISUPPORTQTSQL_DEPRECATED_EXPORT VTKGUISUPPORTQTSQL_EXPORT VTKGUISUPPORTQTSQL_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkIOSQLModule.h"
-
+#ifndef VTKGUISUPPORTQTSQL_DEPRECATED_NO_EXPORT
+#  define VTKGUISUPPORTQTSQL_DEPRECATED_NO_EXPORT VTKGUISUPPORTQTSQL_NO_EXPORT VTKGUISUPPORTQTSQL_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKGUISUPPORTQTSQL_NO_DEPRECATED
+#    define VTKGUISUPPORTQTSQL_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKGUISUPPORTQTSQL_EXPORT_H */
